@@ -31,6 +31,10 @@
 #include "inhibit.h"
 #include "notification.h"
 #include "print.h"
+#if SCREENCAST_ENABLED
+#include "screencast.h"
+#endif
+#include "screenshot.h"
 
 class DesktopPortal : public QObject
 {
@@ -47,6 +51,10 @@ private:
     InhibitPortal *m_inhibit;
     NotificationPortal *m_notification;
     PrintPortal *m_print;
+#if SCREENCAST_ENABLED
+    ScreenCastPortal *m_screenCast;
+#endif
+    ScreenshotPortal *m_screenshot;
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_DESKTOP_PORTAL_H
